@@ -6,9 +6,10 @@
 
 # GlobalChemExtensions Import
 
-# Molecule
+# Entities
 
-from global_chem_extensions.molecule.molecule import GlobalChemMolecule
+from global_chem_extensions.entities.molecule.molecule import GlobalChemMolecule
+from global_chem_extensions.entities.protein.protein import GlobalChemProtein
 
 # Visualization
 
@@ -329,6 +330,7 @@ class GlobalChemExtensions(object):
             molvs=False,
             deepsmiles=False,
             partial=False,
+            selfies=False,
             return_failures=False
     ):
 
@@ -342,6 +344,7 @@ class GlobalChemExtensions(object):
             molvs (Bool): Whether to pass the validation through MolVS
             deepsmiles (Bool): deepSMILES validation for machine learning
             partial (Bool): whether the user would like to have partial fragments
+            selfies (Bool): whether the user would like to pass in the selfies for machine learning
             return_failures (Bool): whether the user would like to have failures returned.
 
         '''
@@ -356,7 +359,8 @@ class GlobalChemExtensions(object):
             partial_smiles=partial_smiles,
             pysmiles=pysmiles,
             molvs=molvs,
-            deepsmiles=deepsmiles
+            deepsmiles=deepsmiles,
+            selfies=selfies
         )
 
         if return_failures:
@@ -469,21 +473,53 @@ class GlobalChemExtensions(object):
         return decoded_list
 
     @staticmethod
-    def initialize_globalchem_molecule(smiles):
+    def initialize_globalchem_molecule(
+            smiles,
+            stream_file='cgenff.str',
+            frcmod_file='gaff2.frcmod',
+    ):
 
         '''
 
         Arguments:
             smiles (String): A smiles string
+            stream_file (String): stream file for CGenFF
+            frcmod_file (String): FRCMOD file for GAFF2
 
         '''
 
         global_chem_molecule = GlobalChemMolecule(
-            smiles=smiles
+            smiles=smiles,
+            stream_file=stream_file,
+            frcmod_file=frcmod_file,
+            cgenff_molecule = CGenFFMolecule,
+            gaff2_molecule = GaFF2Molecule
         )
 
         return global_chem_molecule
 
+    @staticmethod
+    def initialize_globalchem_protein(
+            pdb_id = None,
+            pdb_path = None,
+            peptide_sequence = None
+    ):
+        '''
+
+        Arguments:
+            pdb_id (String): pdb id unique 4 letter code
+            pdb_path (String): path to the pdb file
+            peptide_sequence (String): Peptide sequence
+        '''
+
+        global_chem_protein = GlobalChemProtein(
+            pdb_file = pdb_id,
+            fetch_pdb = pdb_path,
+            peptide_sequence = peptide_sequence,
+        )
+
+        return global_chem_protein
+
     @staticmethod
     def initialize_cgenff_molecule(stream_file):
 
